/* Form definition file generated with fdesign. */

#include "forms.h"
#include <stdlib.h>
#include "xdvips.h"

FD_fr1 *create_form_fr1(void)
{
  FL_OBJECT *obj;
  FD_fr1 *fdui = (FD_fr1 *) fl_calloc(1, sizeof(*fdui));

  fdui->fr1 = fl_bgn_form(FL_NO_BOX, 300, 340);
  obj = fl_add_box(FL_UP_BOX,0,0,300,340,"");

  fdui->gr_all = fl_bgn_group();
  obj = fl_add_frame(FL_ENGRAVED_FRAME,10,290,280,40,"");
  obj = fl_add_button(FL_NORMAL_BUTTON,230,295,50,30,"Print");
    fl_set_button_shortcut(obj,"#p",1);
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
    fl_set_object_callback(obj,f_print,0);
  obj = fl_add_button(FL_NORMAL_BUTTON,110,295,80,30,"Create File");
    fl_set_button_shortcut(obj,"#c",1);
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
    fl_set_object_callback(obj,f_create,0);
  obj = fl_add_button(FL_NORMAL_BUTTON,20,295,50,30,"Quit");
    fl_set_button_shortcut(obj,"#q",1);
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
    fl_set_object_callback(obj,f_quit,0);
  fdui->file_in = obj = fl_add_input(FL_NORMAL_INPUT,100,20,170,20,"");
    fl_set_object_callback(obj,f_dummy,0);
  fdui->first_in = obj = fl_add_input(FL_NORMAL_INPUT,100,40,170,20,"");
    fl_set_object_callback(obj,f_dummy,0);
  fdui->last_in = obj = fl_add_input(FL_NORMAL_INPUT,100,60,170,20,"");
    fl_set_object_callback(obj,f_dummy,0);
  fdui->x_res_in = obj = fl_add_input(FL_NORMAL_INPUT,100,80,170,20,"");
    fl_set_object_callback(obj,f_dummy,0);
  fdui->y_res_in = obj = fl_add_input(FL_NORMAL_INPUT,100,100,170,20,"");
    fl_set_object_callback(obj,f_dummy,0);
  fdui->x_off_in = obj = fl_add_input(FL_NORMAL_INPUT,100,120,170,20,"");
    fl_set_object_callback(obj,f_dummy,0);
  fdui->y_off_in = obj = fl_add_input(FL_NORMAL_INPUT,100,140,170,20,"");
    fl_set_object_callback(obj,f_dummy,0);
  fdui->paper_ch = obj = fl_add_choice(FL_DROPLIST_CHOICE,100,170,170,20,"Paper format");
    fl_set_object_shortcut(obj,"#f",1);
    fl_set_object_boxtype(obj,FL_DOWN_BOX);
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
    fl_set_object_callback(obj,f_dummy,0);
  fdui->printer_ch = obj = fl_add_choice(FL_DROPLIST_CHOICE,100,200,170,20,"Printer");
    fl_set_object_shortcut(obj,"#i",1);
    fl_set_object_boxtype(obj,FL_DOWN_BOX);
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
    fl_set_object_callback(obj,f_dummy,0);
  obj = fl_add_button(FL_NORMAL_BUTTON,270,20,20,20,"O");
    fl_set_object_callback(obj,f_open,0);
  fdui->rev_button = obj = fl_add_checkbutton(FL_PUSH_BUTTON,20,250,160,20,"Print in reverse order");
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
    fl_set_object_callback(obj,f_dummy,0);
  obj = fl_add_text(FL_NORMAL_TEXT,30,20,70,20,"Filename");
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lalign(obj,FL_ALIGN_RIGHT|FL_ALIGN_INSIDE);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
  obj = fl_add_text(FL_NORMAL_TEXT,30,40,70,20,"First page");
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lalign(obj,FL_ALIGN_RIGHT|FL_ALIGN_INSIDE);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
  obj = fl_add_text(FL_NORMAL_TEXT,30,60,70,20,"Last Page");
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lalign(obj,FL_ALIGN_RIGHT|FL_ALIGN_INSIDE);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
  obj = fl_add_text(FL_NORMAL_TEXT,10,80,90,20,"X-Resolution");
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lalign(obj,FL_ALIGN_RIGHT|FL_ALIGN_INSIDE);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
  obj = fl_add_text(FL_NORMAL_TEXT,10,100,90,20,"Y-Resolution");
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lalign(obj,FL_ALIGN_RIGHT|FL_ALIGN_INSIDE);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
  obj = fl_add_text(FL_NORMAL_TEXT,30,120,70,20,"X-Offset");
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lalign(obj,FL_ALIGN_RIGHT|FL_ALIGN_INSIDE);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
  obj = fl_add_text(FL_NORMAL_TEXT,30,140,70,20,"Y-Offset");
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lalign(obj,FL_ALIGN_RIGHT|FL_ALIGN_INSIDE);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
  obj = fl_add_button(FL_NORMAL_BUTTON,280,280,10,10,"");
    fl_set_object_callback(obj,f_version,0);
  fdui->odd_button = obj = fl_add_checkbutton(FL_RADIO_BUTTON,100,230,90,20,"Odd Pages");
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
    fl_set_object_callback(obj,f_pages,2);
  fdui->all_button = obj = fl_add_checkbutton(FL_RADIO_BUTTON,20,230,80,20,"All Pages");
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
    fl_set_object_callback(obj,f_pages,1);
  fdui->even_button = obj = fl_add_checkbutton(FL_RADIO_BUTTON,190,230,100,20,"Even Pages");
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
    fl_set_object_callback(obj,f_pages,3);
  fl_end_group();

  fdui->x_res_but = obj = fl_add_checkbutton(FL_PUSH_BUTTON,270,80,20,20,"");
    fl_set_object_callback(obj,f_dummy,0);
  fdui->y_res_but = obj = fl_add_checkbutton(FL_PUSH_BUTTON,270,100,20,20,"");
    fl_set_object_callback(obj,f_dummy,0);
  fdui->printer_but = obj = fl_add_checkbutton(FL_PUSH_BUTTON,270,200,20,20,"");
    fl_set_object_callback(obj,f_dummy,0);
  fl_end_form();

  return fdui;
}
/*---------------------------------------*/

