#ifndef FD_fr1_h_
#define FD_fr1_h_
/* Header file generated with fdesign. */

/**** Callback routines ****/

extern void f_print(FL_OBJECT *, long);
extern void f_create(FL_OBJECT *, long);
extern void f_quit(FL_OBJECT *, long);
extern void f_dummy(FL_OBJECT *, long);
extern void f_open(FL_OBJECT *, long);
extern void f_version(FL_OBJECT *, long);
extern void f_pages(FL_OBJECT *, long);


/**** Forms and Objects ****/

typedef struct {
	FL_FORM *fr1;
	FL_OBJECT *gr_all;
	FL_OBJECT *file_in;
	FL_OBJECT *first_in;
	FL_OBJECT *last_in;
	FL_OBJECT *x_res_in;
	FL_OBJECT *y_res_in;
	FL_OBJECT *x_off_in;
	FL_OBJECT *y_off_in;
	FL_OBJECT *paper_ch;
	FL_OBJECT *printer_ch;
	FL_OBJECT *rev_button;
	FL_OBJECT *odd_button;
	FL_OBJECT *all_button;
	FL_OBJECT *even_button;
	FL_OBJECT *x_res_but;
	FL_OBJECT *y_res_but;
	FL_OBJECT *printer_but;
	void *vdata;
	long ldata;
} FD_fr1;

extern FD_fr1 * create_form_fr1(void);

#endif /* FD_fr1_h_ */
